<img src="https://img.shields.io/github/license/TralahM/pytek-wasiliana"> <img src="https://img.shields.io/github/last-commit/TralahM/pytek-wasiliana"> <img src="https://img.shields.io/github/contributors/TralahM/pytek-wasiliana"> <img src="https://img.shields.io/github/issues-pr-raw/TralahM/pytek-wasiliana?color=blue"> <img src="https://img.shields.io/github/issues-pr-closed-raw/TralahM/pytek-wasiliana?color=red"> <img src="https://img.shields.io/github/issues-raw/TralahM/pytek-wasiliana?color=green">
<img src="https://img.shields.io/github/issues-closed-raw/TralahM/pytek-wasiliana?color=yellow"> <img src="https://img.shields.io/github/forks/TralahM/pytek-wasiliana?label=Forks&style=social"> <img src="https://img.shields.io/github/forks/TralahM/pytek-wasiliana?label=Forks&style=social"> <img src="https://img.shields.io/github/stars/TralahM/pytek-wasiliana?style=social">
<img src="https://img.shields.io/github/watchers/TralahM/pytek-wasiliana?label=Watch&style=social"> <img src="https://img.shields.io/github/downloads/TralahM/pytek-wasiliana/total"> <img src="https://img.shields.io/github/repo-size/TralahM/pytek-wasiliana"> <img src="https://img.shields.io/github/languages/count/TralahM/pytek-wasiliana"> <img src="https://img.shields.io/github/v/tag/TralahM/pytek-wasiliana"> <img src="https://img.shields.io/readthedocs/pytek-wasiliana"> <img src="https://img.shields.io/pypi/v/pytek-wasiliana"> <img src="https://img.shields.io/pypi/pyversions/pytek-wasiliana"> <img src="https://img.shields.io/pypi/wheel/pytek-wasiliana"> <img src="https://img.shields.io/pypi/status/pytek-wasiliana?label=pypi%20status"> <img src="https://img.shields.io/pypi/format/pytek-wasiliana?label=pypi%20format">

# pytek-wasiliana
> Wasiliana USSD and SMS API SDK

---

### Table of Contents
- [QuickStart](#QuickStart)
- [Documentation/Usage](#Documentation)
- [Contributing](#Contributing)
- [Credits](#Credits)

---
## QuickStart
#### Installation

```
pip install pytek-wasiliana
```
#### From Source
```
git clone https://github.com/TralahM/pytek-wasiliana
cd pytek-wasiliana

```
---

## Documentation

[![Documentation](https://img.shields.io/badge/Docs-pytek-wasiliana-blue.svg?style=for-the-badge)](https://pytek-wasiliana.readthedocs.io)


#### API Reference

---
## Contributing

---

## Credits
[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-black.svg?style=for-the-badge&logo=github)](https://github.com/TralahTek)
[![TralahM](https://img.shields.io/badge/Engineer-TralahM-blue.svg?style=for-the-badge&logo=github)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Maintainer-TralahM-green.svg?style=for-the-badge&logo=github)](https://github.com/TralahM)



[![](https://img.shields.io/badge/Github-TralahM-green?style=for-the-badge&logo=github)](https://github.com/TralahM)
[![](https://img.shields.io/badge/Twitter-%40tralahtek-blue?style=for-the-badge&logo=twitter)](https://twitter.com/TralahM)
[![TralahM](https://img.shields.io/badge/Kaggle-TralahM-purple.svg?style=for-the-badge&logo=kaggle)](https://kaggle.com/TralahM)
[![TralahM](https://img.shields.io/badge/LinkedIn-TralahM-white.svg?style=for-the-badge&logo=linkedin)](https://linkedin.com/in/TralahM)


[![Blog](https://img.shields.io/badge/Blog-tralahm.tralahtek.com-blue.svg?style=for-the-badge&logo=rss)](https://tralahm.tralahtek.com)

[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-cyan.svg?style=for-the-badge)](https://org.tralahtek.com)
---